@@ -1,8 +1,10 @@
 
 (IN-PACKAGE "COMPILER") 
 
+(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM) T) DASH-TO-UNDERSCORE-INT))
+(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T) T) C-FUNCTION-NAME))
 (PROCLAIM '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MLIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T)  COPY-ARRAY COPY-INFO)) 
+(PROCLAIM '(FTYPE (FUNCTION (T) T)  COPY-ARRAY COPY-INFO DASH-TO-UNDERSCORE)) 
 (PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM T) FIXNUM)  PUSH-ARRAY)) 
 (PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM FIXNUM T) FIXNUM) BSEARCHLEQ)) 
 (PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) F-TYPE)) 
@@ -27,8 +29,8 @@
             ADD-FUNCTION-PROCLAMATION ADD-FUNCTION-DECLARATION
             CAN-BE-REPLACED* GET-INLINE-INFO C2LET* SUBLIS1-INLINE
             CHECK-VDECL C2TAGBODY C2GO C2CASE AND-FORM-TYPE
-            CHECK-FORM-TYPE C2FUNCALL-SFUN ADD-FAST-LINK
-            INLINE-TYPE-MATCHES CJF C2LET)) 
+            CHECK-FORM-TYPE C2FUNCALL-SFUN ADD-FAST-LINK WT-MAKE-CCLOSURE
+            INLINE-TYPE-MATCHES CJF C2LET MAKE-INLINE-STRING)) 
 (PROCLAIM
     '(FTYPE (FUNCTION (T T *) T) INLINE-ARGS C2FUNCALL C2LAMBDA-EXPR)) 
 (PROCLAIM
@@ -74,7 +76,7 @@
             PROCLAMATION C1MAPC C1MAPL WT-H1 C1VAR T1PROGN
             CHECK-DOWNWARD C1MAPCAN C1FMLA-CONSTANT CHECK-VREF C1MAPCON
             ADD-SYMBOL WT-VS* FLAGS-POS C1VREF C1CATCH VARARG-P MAXARGS
-            INFO-CHANGED-VARS C1EXPR C1UNWIND-PROTECT
+            INFO-CHANGED-VARS C1EXPR C1UNWIND-PROTECT ADD-ADDRESS
             C1MULTIPLE-VALUE-CALL INFO-REFERRED-VARS
             INLINE-BOOLE3-STRING INFO-TYPE AET-C-TYPE RESULT-TYPE
             C1THROW C1MULTIPLE-VALUE-PROG1 C2DM-RESERVE-VL
@@ -133,7 +135,7 @@
             SHIFT>> SHIFT<< COMPILER-CLEAR-COMPILER-PROPERTIES
             MAYBE-EVAL PUSH-CHANGED-VARS SET-JUMP-TRUE C2BLOCK-CCB
             C2DM-BIND-VL C1CONSTANT-VALUE C2BLOCK-CLB CMPFIX-ARGS
-            C1LAMBDA-FUN MAKE-INLINE-STRING CO1CONSTANT-FOLD
+            C1LAMBDA-FUN CO1CONSTANT-FOLD
             C2LAMBDA-EXPR-WITH-KEY C1ARGS MULTIPLE-VALUE-CHECK
             C2LAMBDA-EXPR-WITHOUT-KEY C2CATCH C2EXPR-TOP C1EXPR*
             C2UNWIND-PROTECT C2RETURN-CCB ADD-DEBUG-INFO
@@ -141,8 +143,8 @@
             C2MULTIPLE-VALUE-PROG1 WT-REQUIREDS C2DM-BIND-LOC C1FMLA
             C2DM-BIND-INIT FAST-READ WT-V*-MACROS CFAST-WRITE
             C2MULTIPLE-VALUE-SETQ WT-MAKE-DCLOSURE C2APPLY C2EXPR-TOP*
-            C1PROGN* COMPILER-DEF-HOOK ADD-ADDRESS C2MEMBER!2
-            T2SHARP-COMMA C2ASSOC!2 SYSTEM::ADD-DEBUG WT-MAKE-CCLOSURE
+            C1PROGN* COMPILER-DEF-HOOK C2MEMBER!2
+            T2SHARP-COMMA C2ASSOC!2 SYSTEM::ADD-DEBUG
             C2LIST-NTH-IMMEDIATE SET-DBIND CONVERT-CASE-TO-SWITCH
             PROCLAIM-VAR CO1LDB CO1EQL COERCE-LOC
             ARGS-INFO-CHANGED-VARS CO1TYPEP JUMPS-TO-P CO1SCHAR CO1CONS
