@@ -824,6 +824,15 @@ init_tm(enum type t, char *name, int elsize, int nelts, int sgc,int distinct) {
   
 }
 
+/* FIXME this is a work-around for the special MacOSX memory
+   initialization sequence, which sets heap_end, traditionally
+   initialized in gcl_init_alloc.  Mac and windows have non-std
+   sbrk-emulating memory subsystems, and their internals need to be
+   homogenized and integrated into the traditional unix sequence for
+   simplicity.  set_maxpage is overloaded, and the positioning of its
+   call is too fragile.  20050115 CM*/
+static int gcl_alloc_initialized;
+
 void
 set_maxpage(void) {
 
@@ -832,7 +841,7 @@ set_maxpage(void) {
 #ifdef SGC
   page_multiple=getpagesize()/PAGESIZE;
   if (page_multiple==0) error("PAGESIZE must be factor of getpagesize()");
-  if (heap_end) {
+  if (gcl_alloc_initialized) {
     extern long maxpage;
     maxpage=page(heap_end);
     memory_protect(sgc_enabled ? 1 : 0);
@@ -854,14 +863,12 @@ void
 gcl_init_alloc(void) {
 
   long i;
-  static int initialized;
 #ifdef GCL_GPROF
    extern void *GCL_GPROF_START;
    unsigned textpage=2*((void *)&etext-(void *)&GCL_GPROF_START)/PAGESIZE;
 #endif
   
-  if (initialized) return;
-  initialized=1;
+  if (gcl_alloc_initialized) return;
   
   
 #ifdef BSD
@@ -985,6 +992,7 @@ gcl_init_alloc(void) {
   if (maxcbpage<textpage)
      maxcbpage=textpage;
 #endif
+  gcl_alloc_initialized=1;
   
 }
 
@@ -1485,6 +1493,16 @@ malloc(size_t size) {
 	     	RECREATE_HEAP
 #endif
 		;
+#ifdef       __MINGW32__ 
+                   /* If malloc() gets called by the C runtime before 
+                    * main starts and the shared memory is not yet 
+                    * initialised causing boofo. 
+                    * SET_REAL_MAXPAGE calls init_shared_memory(). 
+                    * This problem arose with gcc 3.4.2 and new libs. 
+                    */ 
+                   SET_REAL_MAXPAGE 
+                   ; 
+#endif 
 	   }
 	}
 
