@@ -2259,6 +2259,12 @@ L:
 	}
 	RETURN1 (x ==0 ? Cnil : x);  
 }
+object 
+fLformat_1(object strm, object control,object x) {
+  VFUN_NARGS=3;
+  return FFN(fLformat)(strm,control,x);
+
+}
 
 /*  object c_apply_n(long int (*fn) (), int n, object *x); */
 
@@ -2273,7 +2279,7 @@ fmt_error(char *s)
 
 DEFVAR("*INDENT-FORMATTED-OUTPUT*",sSAindent_formatted_outputA,SI,Cnil,"");
 void
-init_format(void)
+gcl_init_format(void)
 {
 	fmt_temporary_stream = make_string_output_stream(64);
 	enter_mark_origin(&fmt_temporary_stream);
