@@ -82,6 +82,7 @@ char stdout_buf[BUFSIZ + EXTRA_BUFSIZE];
 
 int debug;			/* debug switch */
 int initflag = FALSE;		/* initialized flag */
+int raw_image = FALSE;		/* raw or saved image */
 
 long real_maxpage;
 object sSAlisp_maxpagesA;
@@ -325,6 +326,10 @@ main(int argc, char **argv, char **envp) {
 #ifdef SGC
 	memprotect_test_reset();
 #endif
+#ifdef GCL_GPROF
+	if (atexit(gprof_cleanup))
+	  error("Cannot setup gprof_cleanup on exit");
+#endif
 
 	if (initflag) {
 		if (saving_system) {
@@ -400,6 +405,8 @@ main(int argc, char **argv, char **envp) {
 
 	interrupt_enable = TRUE;
 
+	raw_image=TRUE;
+
 	super_funcall(sStop_level);
 
 	return 0;
@@ -925,8 +932,10 @@ FFN(siLsave_system)(void) {
     saving_system = TRUE;
   GBC(t_contiguous);
   
-  
-  
+#ifdef GCL_GPROF
+  gprof_cleanup();
+#endif
+    
 #if defined(BSD) || defined(ATT)  
   brk(core_end);
   /* printf( "(breaking at core_end = %x in main ,)",core_end); */
@@ -942,10 +951,10 @@ FFN(siLsave_system)(void) {
   
   
 /*  #endif */
-  cbgbccount = tm_table[t_contiguous].tm_adjgbccnt = 0;
-  rbgbccount = tm_table[t_relocatable].tm_adjgbccnt = 0;
+  cbgbccount = tm_table[t_contiguous].tm_adjgbccnt = tm_table[t_contiguous].tm_opt_maxpage = 0;
+  rbgbccount = tm_table[t_relocatable].tm_adjgbccnt = tm_table[t_relocatable].tm_opt_maxpage = 0;
   for (i = 0;  i < (int)t_end;  i++)
-    tm_table[i].tm_gbccount = tm_table[i].tm_adjgbccnt = 0;
+    tm_table[i].tm_gbccount = tm_table[i].tm_adjgbccnt = tm_table[i].tm_opt_maxpage = 0;
   Lsave();
   saving_system = FALSE;
   alloc_page(-(holepage+nrbpage));
@@ -998,6 +1007,9 @@ init_main(void) {
 #ifdef GMP
   ADD_FEATURE("GMP");
 #endif	 
+#ifdef GCL_GPROF
+  ADD_FEATURE("GPROF");
+#endif	 
   
 #ifdef UNIX
 #ifndef _WIN32	 
